===============================
Welcome to networking-omnipath!
===============================

.. Team and repository tags
   # TBD

.. Change things from this point on

Summary
-------

OpenStack networking-omnipath is a ML2 mechanism driver that integrates
OpenStack Neutron API with Omnipath backend. It enables Omnipath switching
fabric in OpenStack cloud and each network in openstack networking realm
corresponds to a virtual fabric on omnipath side.

To report and discover bugs in networking-omnipath the following
link can be used:
(TBD)

Any new code submission or proposal must follow the development
guidelines detailed in HACKING.rst and for further details this
link can be checked:
(TBD)

Release notes for the project can be found at:
(TBD)

The project source code repository is located at:
(TBD)
